@@ -481,6 +481,15 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
         self.stop_appium()
         self.reset()
 
+    def check_alert(self):
+        result_flag = False
+        try:
+            alert = self.driver.switch_to.alert
+            result_flag = True
+        except:
+            pass
+        return result_flag
+
     def write(self, msg, level='info'):
         "Log the message"
         self.msg_list.append('%-8s:  ' % level.upper() + msg)
